@@ -90,7 +90,7 @@ class FunctionalTests(testtools.TestCase):
                 self.assertEqual(expect[k], m["_totals"][k])
         # test issue counts
         if "issues" in expect:
-            for (criteria, default) in C.CRITERIA:
+            for criteria, default in C.CRITERIA:
                 for rank in C.RANKING:
                     label = f"{criteria}.{rank}"
                     expected = 0
@@ -113,14 +113,14 @@ class FunctionalTests(testtools.TestCase):
                 "SEVERITY": {
                     "UNDEFINED": 0,
                     "LOW": 0,
-                    "MEDIUM": 10,
+                    "MEDIUM": 16,
                     "HIGH": 9,
                 },
                 "CONFIDENCE": {
                     "UNDEFINED": 0,
                     "LOW": 0,
                     "MEDIUM": 0,
-                    "HIGH": 19,
+                    "HIGH": 25,
                 },
             }
         else:
@@ -128,14 +128,14 @@ class FunctionalTests(testtools.TestCase):
                 "SEVERITY": {
                     "UNDEFINED": 0,
                     "LOW": 0,
-                    "MEDIUM": 16,
+                    "MEDIUM": 22,
                     "HIGH": 4,
                 },
                 "CONFIDENCE": {
                     "UNDEFINED": 0,
                     "LOW": 0,
                     "MEDIUM": 0,
-                    "HIGH": 20,
+                    "HIGH": 26,
                 },
             }
         self.check_example("crypto-md5.py", expect)
@@ -396,8 +396,8 @@ class FunctionalTests(testtools.TestCase):
     def test_random_module(self):
         """Test for the `random` module."""
         expect = {
-            "SEVERITY": {"UNDEFINED": 0, "LOW": 7, "MEDIUM": 0, "HIGH": 0},
-            "CONFIDENCE": {"UNDEFINED": 0, "LOW": 0, "MEDIUM": 0, "HIGH": 7},
+            "SEVERITY": {"UNDEFINED": 0, "LOW": 8, "MEDIUM": 0, "HIGH": 0},
+            "CONFIDENCE": {"UNDEFINED": 0, "LOW": 0, "MEDIUM": 0, "HIGH": 8},
         }
         self.check_example("random_module.py", expect)
 
@@ -461,18 +461,6 @@ class FunctionalTests(testtools.TestCase):
         severity_medium_tests = 26
         nosec_tests = 7
         skipped_tests = 8
-        if sys.version_info[:2] <= (3, 7):
-            # In the case of implicit concatenation in python 3.7,
-            # we know only the first line of multi-line string.
-            # Thus, cases like:
-            # query = ("SELECT * "
-            #          "FROM foo "  # nosec
-            #          f"WHERE id = {identifier}")
-            # are not skipped but reported as errors.
-            confidence_low_tests = 17
-            severity_medium_tests = 30
-            nosec_tests = 5
-            skipped_tests = 6
         expect = {
             "SEVERITY": {
                 "UNDEFINED": 0,
@@ -513,8 +501,8 @@ class FunctionalTests(testtools.TestCase):
     def test_urlopen(self):
         """Test for dangerous URL opening."""
         expect = {
-            "SEVERITY": {"UNDEFINED": 0, "LOW": 0, "MEDIUM": 14, "HIGH": 0},
-            "CONFIDENCE": {"UNDEFINED": 0, "LOW": 0, "MEDIUM": 0, "HIGH": 14},
+            "SEVERITY": {"UNDEFINED": 0, "LOW": 0, "MEDIUM": 8, "HIGH": 0},
+            "CONFIDENCE": {"UNDEFINED": 0, "LOW": 0, "MEDIUM": 0, "HIGH": 8},
         }
         self.check_example("urlopen.py", expect)
 
@@ -539,8 +527,8 @@ class FunctionalTests(testtools.TestCase):
         """Test insecure raw functions on Django."""
 
         expect = {
-            "SEVERITY": {"UNDEFINED": 0, "LOW": 0, "MEDIUM": 4, "HIGH": 0},
-            "CONFIDENCE": {"UNDEFINED": 0, "LOW": 0, "MEDIUM": 4, "HIGH": 0},
+            "SEVERITY": {"UNDEFINED": 0, "LOW": 0, "MEDIUM": 6, "HIGH": 0},
+            "CONFIDENCE": {"UNDEFINED": 0, "LOW": 0, "MEDIUM": 6, "HIGH": 0},
         }
         self.check_example("django_sql_injection_raw.py", expect)
 
@@ -555,8 +543,8 @@ class FunctionalTests(testtools.TestCase):
     def test_host_key_verification(self):
         """Test for ignoring host key verification."""
         expect = {
-            "SEVERITY": {"UNDEFINED": 0, "LOW": 0, "MEDIUM": 0, "HIGH": 2},
-            "CONFIDENCE": {"UNDEFINED": 0, "LOW": 0, "MEDIUM": 2, "HIGH": 0},
+            "SEVERITY": {"UNDEFINED": 0, "LOW": 0, "MEDIUM": 0, "HIGH": 4},
+            "CONFIDENCE": {"UNDEFINED": 0, "LOW": 0, "MEDIUM": 4, "HIGH": 0},
         }
         self.check_example("no_host_key_verification.py", expect)
 
@@ -790,19 +778,13 @@ class FunctionalTests(testtools.TestCase):
             issues[0].fname.endswith("examples/multiline_statement.py")
         )
         self.assertEqual(1, issues[0].lineno)
-        if sys.version_info >= (3, 8):
-            self.assertEqual(list(range(1, 2)), issues[0].linerange)
-        else:
-            self.assertEqual(list(range(1, 3)), issues[0].linerange)
+        self.assertEqual(list(range(1, 2)), issues[0].linerange)
         self.assertIn("subprocess", issues[0].get_code())
         self.assertEqual(5, issues[1].lineno)
         self.assertEqual(list(range(3, 6 + 1)), issues[1].linerange)
         self.assertIn("shell=True", issues[1].get_code())
         self.assertEqual(11, issues[2].lineno)
-        if sys.version_info >= (3, 8):
-            self.assertEqual(list(range(8, 13 + 1)), issues[2].linerange)
-        else:
-            self.assertEqual(list(range(8, 12 + 1)), issues[2].linerange)
+        self.assertEqual(list(range(8, 13 + 1)), issues[2].linerange)
         self.assertIn("shell=True", issues[2].get_code())
 
     def test_code_line_numbers(self):
@@ -835,18 +817,18 @@ class FunctionalTests(testtools.TestCase):
             "exposes the Werkzeug debugger and allows the execution "
             "of arbitrary code."
         )
-        json = """{{
+        json = f"""{{
           "results": [
             {{
               "code": "...",
-              "filename": "{}/examples/flask_debug.py",
+              "filename": "{os.getcwd()}/examples/flask_debug.py",
               "issue_confidence": "MEDIUM",
               "issue_severity": "HIGH",
               "issue_cwe": {{
                 "id": 94,
                 "link": "https://cwe.mitre.org/data/definitions/94.html"
               }},
-              "issue_text": "{}",
+              "issue_text": "{issue_text}",
               "line_number": 10,
               "col_offset": 0,
               "line_range": [
@@ -857,10 +839,7 @@ class FunctionalTests(testtools.TestCase):
             }}
           ]
         }}
-        """.format(
-            os.getcwd(),
-            issue_text,
-        )
+        """
 
         self.b_mgr.populate_baseline(json)
         self.run_example("flask_debug.py")
